pub struct Config {Show 16 fields
pub owner: Addr,
pub factory_contract: Addr,
pub staking_contract: Option<Addr>,
pub dev_fund_conf: Option<DevFundConfig>,
pub default_bridge: Option<AssetInfo>,
pub governance_contract: Option<Addr>,
pub governance_percent: Uint64,
pub astro_token: AssetInfo,
pub max_spread: Decimal,
pub rewards_enabled: bool,
pub pre_upgrade_blocks: u64,
pub last_distribution_block: u64,
pub remainder_reward: Uint128,
pub pre_upgrade_astro_amount: Uint128,
pub second_receiver_cfg: Option<SecondReceiverConfig>,
pub collect_cooldown: Option<u64>,
}Expand description
This structure stores the main parameters for the Maker contract.
Fields
owner: AddrAddress that’s allowed to set contract parameters
factory_contract: AddrThe factory contract address
staking_contract: Option<Addr>The xASTRO staking contract address.
dev_fund_conf: Option<DevFundConfig>The dev fund configuration
default_bridge: Option<AssetInfo>Default bridge asset (Terra1 - LUNC, Terra2 - LUNA, etc.)
governance_contract: Option<Addr>The vxASTRO fee distributor contract address
governance_percent: Uint64The percentage of fees that go to the vxASTRO fee distributor
astro_token: AssetInfoThe ASTRO token asset info
max_spread: DecimalThe max spread allowed when swapping fee tokens to ASTRO
rewards_enabled: boolThe flag which determines whether accrued ASTRO from fee swaps is being distributed or not
pre_upgrade_blocks: u64The number of blocks over which ASTRO that accrued pre-upgrade will be distributed
last_distribution_block: u64The last block until which pre-upgrade ASTRO will be distributed
remainder_reward: Uint128The remainder of pre-upgrade ASTRO to distribute
pre_upgrade_astro_amount: Uint128The amount of collected ASTRO before enabling rewards distribution
second_receiver_cfg: Option<SecondReceiverConfig>Parameters that describe the second receiver of fees
collect_cooldown: Option<u64>If set defines the period when maker collect can be called