pub enum ExecuteMsgExt<C> {
Receive(Cw20ReceiveMsg),
ProvideLiquidity {
assets: Vec<Asset>,
slippage_tolerance: Option<Decimal>,
auto_stake: Option<bool>,
receiver: Option<String>,
min_lp_to_receive: Option<Uint128>,
},
WithdrawLiquidity {
assets: Vec<Asset>,
min_assets_to_receive: Option<Vec<Asset>>,
},
Swap {
offer_asset: Asset,
ask_asset_info: Option<AssetInfo>,
belief_price: Option<Decimal>,
max_spread: Option<Decimal>,
to: Option<String>,
},
UpdateConfig {
params: Binary,
},
ProposeNewOwner {
owner: String,
expires_in: u64,
},
DropOwnershipProposal {},
ClaimOwnership {},
Custom(C),
}Expand description
This structure describes the execute messages available in the contract.
Variants
Receive(Cw20ReceiveMsg)
Receives a message of type Cw20ReceiveMsg
ProvideLiquidity
ProvideLiquidity allows someone to provide liquidity in the pool
Fields

slippage_tolerance: Option<Decimal>The slippage tolerance that allows liquidity provision only if the price in the pool doesn’t move too much
WithdrawLiquidity
WithdrawLiquidity allows someone to withdraw liquidity from the pool
Swap
Swap performs a swap in the pool
Fields
UpdateConfig
Update the pair configuration
ProposeNewOwner
ProposeNewOwner creates a proposal to change contract ownership.
The validity period for the proposal is set in the expires_in variable.
Fields
DropOwnershipProposal
DropOwnershipProposal removes the existing offer to change contract ownership.
ClaimOwnership
Used to claim contract ownership.
Custom(C)
Custom execute endpoints for extended pool implementations